@@ -1,6 +1,6 @@
 package MongoDBx::Class::Moose;
 BEGIN {
-  $MongoDBx::Class::Moose::VERSION = '0.3';
+  $MongoDBx::Class::Moose::VERSION = '0.4';
 }
 
 # ABSTRACT: Extends Moose with common relationships for MongoDBx::Class documents
@@ -14,7 +14,7 @@ MongoDBx::Class::Moose - Extends Moose with common relationships for MongoDBx::C
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 PROVIDES
 
@@ -36,7 +36,13 @@ L<Moose>
 
 	has 'year' => (is => 'ro', isa => 'Int', predicate => 'has_year', writer => 'set_year');
 
-	has_many 'related_novels' => (is => 'ro', isa => 'MyApp::Schema::Novel', predicate => 'has_related_novels', writer => 'set_related_novels', clearer => 'clear_related_novels');
+	has 'added' => (is => 'ro', isa => 'DateTime', traits => ['Parsed'], required => 1);
+	
+	holds_many 'tags' => (is => 'ro', isa => 'MyApp::Schema::Tag', predicate => 'has_tags');
+
+	joins_one 'synopsis' => (is => 'ro', isa => 'Synopsis', coll => 'synopsis', ref => 'novel');
+
+	has_many 'related_novels' => (is => 'ro', isa => 'Novel', predicate => 'has_related_novels', writer => 'set_related_novels', clearer => 'clear_related_novels');
 
 	joins_many 'reviews' => (is => 'ro', isa => 'Review', coll => 'reviews', ref => 'novel');
 
